"use strict";

exports.__esModule = true;
exports.getActiveElement = getActiveElement;
exports.contains = contains;
exports.cx = exports.getDocument = exports.ariaAttr = exports.dataAttr = exports.isBrowser = exports.getWindow = void 0;
var win;
/**
 * Note: Accessing "window" in IE11 is somewhat expensive, and calling "typeof window"
 * hits a memory leak, whereas aliasing it and calling "typeof win" does not.
 * Caching the window value at the file scope lets us minimize the impact.
 *
 * @see IE11 Memory Leak Issue https://github.com/microsoft/fluentui/pull/9010#issuecomment-490768427
 */

try {
  win = window;
} catch (e) {
  /* no-op */
}
/**
 * Helper to get the window object. The helper will make sure to use a cached variable
 * of "window", to avoid overhead and memory leaks in IE11.
 */


var getWindow = function getWindow(node) {
  var _node$ownerDocument$d, _node$ownerDocument;

  return (_node$ownerDocument$d = node == null ? void 0 : (_node$ownerDocument = node.ownerDocument) == null ? void 0 : _node$ownerDocument.defaultView) != null ? _node$ownerDocument$d : win;
};
/**
 * Check if we can use the DOM. Useful for SSR purposes
 */


exports.getWindow = getWindow;

function checkIsBrowser() {
  var win = getWindow();
  return Boolean(typeof win !== 'undefined' && win.document && win.document.createElement);
}

var isBrowser = checkIsBrowser();
exports.isBrowser = isBrowser;

var dataAttr = function dataAttr(condition) {
  return condition ? '' : undefined;
};

exports.dataAttr = dataAttr;

var ariaAttr = function ariaAttr(condition) {
  return condition ? true : undefined;
};

exports.ariaAttr = ariaAttr;

var getDocument = function getDocument(node) {
  return node != null && node.ownerDocument || isBrowser ? document : null;
};

exports.getDocument = getDocument;

var cx = function cx() {
  for (var _len = arguments.length, classNames = new Array(_len), _key = 0; _key < _len; _key++) {
    classNames[_key] = arguments[_key];
  }

  return classNames.filter(Boolean).join(' ');
};

exports.cx = cx;

function getActiveElement(node) {
  var doc = getDocument(node);
  return doc == null ? void 0 : doc.activeElement;
}

function contains(parent, child) {
  return parent === child || parent.contains(child);
}
//# sourceMappingURL=dom.js.map