"use strict";

exports.__esModule = true;
exports.runIfFn = runIfFn;
exports.callAllHandlers = callAllHandlers;
exports.callAll = callAll;
exports.once = once;
exports.error = exports.warn = exports.noop = void 0;

var _assertion = require("./assertion");

function runIfFn(valueOrFn) {
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  return (0, _assertion.isFunction)(valueOrFn) ? valueOrFn.apply(void 0, args) : valueOrFn;
}

function callAllHandlers() {
  for (var _len2 = arguments.length, fns = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    fns[_key2] = arguments[_key2];
  }

  return function func(event) {
    fns.some(function (fn) {
      fn == null ? void 0 : fn(event);
      return event == null ? void 0 : event.defaultPrevented;
    });
  };
}

function callAll() {
  for (var _len3 = arguments.length, fns = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
    fns[_key3] = arguments[_key3];
  }

  return function mergedFn(arg) {
    fns.forEach(function (fn) {
      fn == null ? void 0 : fn(arg);
    });
  };
}

function once(fn) {
  var result;
  return function func() {
    if (fn) {
      for (var _len4 = arguments.length, args = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
        args[_key4] = arguments[_key4];
      }

      result = fn.apply(this, args);
      fn = null;
    }

    return result;
  };
}

var noop = function noop() {};

exports.noop = noop;
var warn = once(function (options) {
  var condition = options.condition,
      message = options.message;

  if (condition && _assertion.__DEV__) {
    console.warn(message);
  }
});
exports.warn = warn;
var error = once(function (options) {
  var condition = options.condition,
      message = options.message;

  if (condition && _assertion.__DEV__) {
    console.error(message);
  }
});
exports.error = error;
//# sourceMappingURL=function.js.map