import mergeWith from 'lodash.mergewith';
import type { Dict } from './types';
export { default as objectAssign } from 'object-assign';
export declare function omit<T extends Dict, K extends keyof T>(object: T, keys: K[]): Pick<T, Exclude<keyof T, K>>;
export declare function pick<T extends Dict, K extends keyof T>(object: T, keys: K[]): { [P in K]: T[P]; };
export declare function split<T extends Dict, K extends keyof T>(object: T, keys: K[]): [{ [P in K]: T[P]; }, Pick<T, Exclude<keyof T, K>>];
/**
 * Get value from a deeply nested object using a string path.
 * Memoizes the value.
 * @param obj - the object
 * @param path - the string path
 * @param def  - the fallback value
 */
export declare function get(obj: object, path: string | number, fallback?: any, index?: number): any;
declare type Handler = (obj: Readonly<object>, path: string | number, fallback?: any, index?: number) => any;
export declare const memoizedGet: Handler;
/**
 * Get value from deeply nested object, based on path
 * It returns the path value if not found in object
 *
 * @param path - the string path or value
 * @param scale - the string path or value
 */
export declare function getWithDefault(path: any, scale: any): any;
declare type FilterFn<T> = (value: any, key: string, object: T) => boolean;
/**
 * Returns the items of an object that meet the condition specified in a callback function.
 *
 * @param object the object to loop through
 * @param fn The filter function
 */
export declare function objectFilter<T>(object: T, fn: FilterFn<T>): Partial<T>;
export declare const filterUndefined: <T>(object: T) => Partial<T>;
export declare const objectKeys: <T extends Record<string, any>>(obj: T) => (keyof T)[];
/**
 * Object.entries polyfill for Nodev10 compatibility
 */
export declare const fromEntries: <T extends unknown>(entries: [string, any][]) => T;
export { mergeWith };
